@@ -1,4 +1,4 @@
-package Pcore::XMPP v0.3.0;
+package Pcore::XMPP v0.4.0;
 
 use Pcore -dist;
 
@@ -23,7 +23,7 @@ Pcore::XMPP
     H->jabber->sendmsg( 'to_user@gmail.com', 'message' );
 
     # create log channel
-    P->log->add_channel( 'jabber', 'xmpp://username:password@gmail.com?gtalk&to=to_user@gmail.com' );
+    P->log->add( 'Channel-Name', 'xmpp://username:password@gmail.com?gtalk&to=to_user@gmail.com' );
 
 =head1 DESCRIPTION
 
